@@ -2,23 +2,10 @@
     kmime_parsers.h
 
     KMime, the KDE Internet mail/usenet news message library.
-    Copyright (c) 2001 the KMime authors.
+    SPDX-FileCopyrightText: 2001 the KMime authors.
     See file AUTHORS for details
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef __KMIME_PARSERS__
 #define __KMIME_PARSERS__
@@ -56,7 +43,10 @@ public:
     }
 
 private:
-    QByteArray m_src, m_boundary, m_preamble, m_epilouge;
+    QByteArray m_src;
+    const QByteArray m_boundary;
+    QByteArray m_preamble;
+    QByteArray m_epilouge;
     QVector<QByteArray> m_parts;
 };
 
